@@ -77,16 +77,22 @@ def write_kafka_stream(stream: DataFrame, spark_job_conf: dict, output_name):
             .options(**output_conf['kafka_options']) \
             .trigger(processingTime=output_conf['processing_time']) \
             .outputMode("append") \
-            .start() \
-            .awaitTermination()
+            .start()
+    elif output_conf.get('availableNow') is not None:
+        stream \
+            .writeStream \
+            .format("kafka") \
+            .options(**output_conf['kafka_options']) \
+            .trigger(availableNow=output_conf['availableNow']) \
+            .outputMode("append") \
+            .start()
     else:
         stream \
             .writeStream \
             .format("kafka") \
             .options(**output_conf['kafka_options']) \
             .outputMode("append") \
-            .start() \
-            .awaitTermination()
+            .start()
 
 
 ######
@@ -157,7 +163,6 @@ def write_delta(spark_job_conf: dict, output_name: str, df: DataFrame):
         .save(output_conf['delta_options']['location'])
     )
 
-
 def write_delta_no_partitioning(spark_job_conf: dict, output_name: str, df: DataFrame):
     output_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
     create_delta_tables_if_not_exists(output_conf, output_conf['delta_options']['schema'])
